/* importingDialog.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef IMPORTINGDIALOG_H
#define IMPORTINGDIALOG_H

#include "palomaDialog.h"
#include "shellCommand.h"
#include "importListDialog.h"


#include <gtk--.h>
#include <string>
#include <time.h>

class PlaylistProxy;

class ImportingDialog : public PalomaDialog {
public:
  typedef ImportListDialog::Songs Songs;
  typedef ImportListDialog::Song Song;

  // The ImportingDialog steals all the elements from the supplied
  // songs list, leaving it empty.  It thus becomes the owner of the
  // allocated songs in this list, and will free them when it
  // destructs.
  ImportingDialog(const Dataset &data, const Volume &volume,
		  int convert_to_type, const string &root_prefix,
		  Songs &songs);
  ~ImportingDialog();

  void import_success();
  void import_failure();

private:
  void cancel_button_clicked();
  gint delete_timeout();

  void layout_window();
  bool advance();
  bool import_current();

  Gtk_VBox _box1;
  Gtk_Label _song_filename;
  Gtk_ProgressBar _progress_bar;
  Gtk_Label _song_name;
  Gtk_Button _cancel_button;

  int _current_index;

  ShellCommand _shell;
  bool _canceled;

  Volume _volume;
  int _convert_to_type;
  string _root_prefix;
  Songs _songs;
  string _basename_to;
  string _filename_to;
};

#endif
  
  
