/* database.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef DATABASE_H
#define DATABASE_H

#include "queryResult.h"

#include <string>
#include <map>

class Database {
public:
  Database();
  virtual ~Database();

  virtual QueryResult sql_command(string command, 
				  bool return_failures = false)=0;

  virtual bool begin()=0;
  virtual bool commit()=0;
  virtual bool rollback()=0;

  virtual bool has_sequence(const string &name)=0;
  virtual bool create_sequence(const string &name)=0;
  virtual int get_next_sequence(const string &name)=0;

  // concat() returns the formatted expression native to the SQL
  // backend to string-concatenate the two elements.
  virtual string concat(const string &a, const string &b)=0;

  // varchar_i() returns the formatted SQL type description most
  // suitable to the SQL backend for storing a string value of at
  // least the indicated length that may be attached to an index.
  virtual string varchar_i(int size);

  virtual bool has_table(const string &name)=0;

friend class QueryResult;
};

#endif
